<?php
/**
 * Rain by Flutterum functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Rain by Flutterum
 */

if ( ! defined( 'rain_by_flutterum_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'rain_by_flutterum_VERSION', '1.4.5' );
}

if ( ! function_exists( 'rain_by_flutterum_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function rain_by_flutterum_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Rain, use a find and replace
		 * to change 'rain-by-flutterum' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'rain-by-flutterum', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

        // Enable the custom header option.
		add_theme_support( 'custom-header', array(
                'video' => true
            ));

		// This theme uses wp_nav_menu() in one location.
  		function rain_by_flutterum_register_menu() {
  		register_nav_menu('primary',esc_html__( 'Primary Menu', 'rain-by-flutterum' ));
  		}
  		add_action( 'init', 'rain_by_flutterum_register_menu' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'rain_by_flutterum_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'rain_by_flutterum_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 */
function rain_by_flutterum_content_width() {
	$GLOBALS['rain_by_flutterum_content_width'] = apply_filters( 'rain_by_flutterum_content_width', 640 );
}
add_action( 'after_setup_theme', 'rain_by_flutterum_content_width', 0 );

if ( ! isset( $content_width ) )
    $content_width = 640;

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function rain_by_flutterum_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'rain-by-flutterum' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'rain-by-flutterum' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'rain_by_flutterum_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function rain_by_flutterum_scripts() {
	wp_enqueue_style( 'rain-by-flutterum-style', get_stylesheet_uri(), array(), rain_by_flutterum_VERSION );
	wp_style_add_data( 'rain-by-flutterum-style', 'rtl', 'replace' );

	wp_enqueue_script( 'rain-by-flutterum-script', get_template_directory_uri() . '/js/menu.js', array('jquery'), '2.0.8', true );
  		wp_localize_script( 'rain-by-flutterum-script', 'screenReaderText', array(
	   		'expand'   => __( 'Expand child menu', 'rain-by-flutterum' ),
	   		'collapse' => __( 'Collapse child menu', 'rain-by-flutterum' ),
  		));
	wp_enqueue_style('rain-by-flutterum-font-awesome', get_template_directory_uri() . '/font-awesome/all.css');
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'rain_by_flutterum_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

add_action( 'init', 'rain_by_flutterum_add_editor_styles' );
/**
 * Apply theme's stylesheet to the visual editor.
 *
 * @uses add_editor_style() Links a stylesheet to visual editor
 * @uses get_stylesheet_uri() Returns URI of theme stylesheet
 */
function rain_by_flutterum_add_editor_styles() {

    add_editor_style( get_stylesheet_uri() );

}

/**
 * Block editor stuff because if you can't beat 'em, join 'em.
 */

function rain_by_flutterum_setup_theme_supported_features() {
    add_theme_support( 'editor-color-palette', array(
		array(
            'name'  => esc_attr__( 'forest green', 'rain-by-flutterum' ),
            'slug'  => 'forest-green',
            'color' => '#228B22',
        ),
		array(
            'name'  => esc_attr__( 'faded green', 'rain-by-flutterum' ),
            'slug'  => 'faded-green',
            'color' => '#7BC17E',
        ),
		array(
            'name'  => esc_attr__( 'pretty blue', 'rain-by-flutterum' ),
            'slug'  => 'pretty-blue',
            'color' => '#073965',
        ),
		array(
            'name'  => esc_attr__( 'faded blue', 'rain-by-flutterum' ),
            'slug'  => 'faded-blue',
            'color' => '#1B609D',
        ),
        array(
            'name'  => esc_attr__( 'strong magenta', 'rain-by-flutterum' ),
            'slug'  => 'strong-magenta',
            'color' => '#a156b4',
        ),
        array(
            'name'  => esc_attr__( 'light grayish magenta', 'rain-by-flutterum' ),
            'slug'  => 'light-grayish-magenta',
            'color' => '#d0a5db',
        ),
        array(
            'name'  => esc_attr__( 'rust red', 'rain-by-flutterum' ),
            'slug'  => 'rust-red',
            'color' => '#C52C03',
        ),
        array(
            'name'  => esc_attr__( 'faded red', 'rain-by-flutterum' ),
            'slug'  => 'faded-red',
            'color' => '#B86566',
        ),
        array(
            'name'  => esc_attr__( 'very light gray', 'rain-by-flutterum' ),
            'slug'  => 'very-light-gray',
            'color' => '#eee',
        ),
        array(
            'name'  => esc_attr__( 'very dark gray', 'rain-by-flutterum' ),
            'slug'  => 'very-dark-gray',
            'color' => '#444',
        ),
        array(
            'name'  => esc_attr__( 'almost black', 'rain-by-flutterum' ),
            'slug'  => 'almost-black',
            'color' => '#222',
        ),
        array(
            'name'  => esc_attr__( 'black', 'rain-by-flutterum' ),
            'slug'  => 'black',
            'color' => '#000',
        ),
        array(
            'name'  => esc_attr__( 'white', 'rain-by-flutterum' ),
            'slug'  => 'white',
            'color' => '#fff',
        ),
    ) );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'responsive-embeds' );
}
 
add_action( 'after_setup_theme', 'rain_by_flutterum_setup_theme_supported_features' );

wp_register_style( 'rain-by-flutterum-guten-style', get_template_directory_uri() . '/style.css' );
 
register_block_style(
    'core/quote',
    array(
        'name'         => 'fancy-quote',
        'label'        => __( 'Fancy Quote', 'rain-by-flutterum' ),
        'style_handle' => 'rain-by-flutterum-guten-style',
    )
);

function rain_by_flutterum_block_patterns() {

    register_block_pattern(
        'rain-by-flutterum/basic-pattern',
        array(
            'title'       => __( 'Page Intro Blocks', 'rain-by-flutterum' ),
            
            'description' => _x( 'Includes a cover block, followed various sections.', 'Block pattern description', 'rain-by-flutterum' ),
            
            'content'     => "<!-- wp:cover -->\n<div class=\"wp-block-cover has-background-dim\"><div class=\"wp-block-cover__inner-container\"></div></div>\n<!-- /wp:cover -->\n\n<!-- wp:columns -->\n<div class=\"wp-block-columns\"><!-- wp:column -->\n<div class=\"wp-block-column\"><!-- wp:heading -->\n<h2>Heading</h2>\n<!-- /wp:heading -->\n\n<!-- wp:paragraph -->\n<p>Content Area #1</p>\n<!-- /wp:paragraph --></div>\n<!-- /wp:column -->\n\n<!-- wp:column -->\n<div class=\"wp-block-column\"><!-- wp:heading -->\n<h2>Heading</h2>\n<!-- /wp:heading -->\n\n<!-- wp:paragraph -->\n<p>Content Area #2</p>\n<!-- /wp:paragraph --></div>\n<!-- /wp:column --></div>\n<!-- /wp:columns -->\n\n<!-- wp:separator {\"className\":\"is-style-wide\"} -->\n<hr class=\"wp-block-separator is-style-wide\"/>\n<!-- /wp:separator -->\n\n<!-- wp:paragraph -->\n<p>Content Area #3</p>\n<!-- /wp:paragraph -->",
            
            'categories'  => array('header'),
        )
    );

}    
add_action( 'init', 'rain_by_flutterum_block_patterns' );